# Installation

Install the command by using:
```shell
pip install bmde
```

Check that the installation is available with:
```shell
python -m bmde --help
```

You may add an alias to your binary to shorten up the command from `python -m bmde` to `bmde`:
```shell
echo "alias bmde=python -m bmde" >> ~/.bashrc
```

Now, `bmde --help` should have the same result as `python -m bmde --help`